# Code for MAEC Related Malware Idiom
from maec.package.package import Package
from maec.package.malware_subject import (MalwareSubject, MalwareSubjectRelationship, 
                                          MalwareSubjectRelationshipList, MalwareSubjectReference)
from cybox.common import VocabString
from cybox.core import Object
from cybox.objects.file_object import File

# Set up the necessary Package and Malware Subject instances
p = Package()
ms1 = MalwareSubject()
ms2 = MalwareSubject()
ms3 = MalwareSubject()
ms4 = MalwareSubject()

# Set the Malware_Instance_Object_Attributes on the first Malware Subject
ms1.malware_instance_object_attributes = Object()
ms1.malware_instance_object_attributes.properties = File()
ms1.malware_instance_object_attributes.properties.file_name = "dg003_improve_8080_V132.exe"
ms1.malware_instance_object_attributes.properties.size_in_bytes = "196608"
ms1.malware_instance_object_attributes.properties.add_hash("4EC0027BEF4D7E1786A04D021FA8A67F")

# Set the Malware_Instance_Object_Attributes on the second Malware Subject
ms2.malware_instance_object_attributes = Object()
ms2.malware_instance_object_attributes.properties = File()
ms2.malware_instance_object_attributes.properties.file_name = "msvcr.dll"

# Set the Malware_Instance_Object_Attributes on the third Malware Subject
ms3.malware_instance_object_attributes = Object()
ms3.malware_instance_object_attributes.properties = File()
ms3.malware_instance_object_attributes.properties.file_name = "fvcwin32.exe"

# Set the Malware_Instance_Object_Attributes on the fourth Malware Subject
ms4.malware_instance_object_attributes = Object()
ms4.malware_instance_object_attributes.properties = File()
ms4.malware_instance_object_attributes.properties.file_name = "acvcwin32.exe"

# Add the relationships between the Malware Subjects
# Add the ms1 -> ms2 "drops" relationship
ms1.relationships = MalwareSubjectRelationshipList()
ms1_ms2_rel = MalwareSubjectRelationship()
ms1_ms2_rel.type_ = VocabString()
ms1_ms2_rel.type_.value = "drops"
ms1_ms2_rel.type_.xsi_type = "maecVocabs:MalwareSubjectRelationshipTypeVocab-1.0"
ms1_ms2_rel.malware_subject_reference = [MalwareSubjectReference()]
ms1_ms2_rel.malware_subject_reference[0].malware_subject_idref = ms2.id_
ms1.relationships.append(ms1_ms2_rel)
# Add the ms2 -> ms1 "dropped by" relationship
ms2.relationships = MalwareSubjectRelationshipList()
ms2_ms1_rel = MalwareSubjectRelationship()
ms2_ms1_rel.type_ = VocabString()
ms2_ms1_rel.type_.value = "dropped by"
ms2_ms1_rel.type_.xsi_type = "maecVocabs:MalwareSubjectRelationshipTypeVocab-1.0"
ms2_ms1_rel.malware_subject_reference = [MalwareSubjectReference()]
ms2_ms1_rel.malware_subject_reference[0].malware_subject_idref = ms1.id_
ms2.relationships.append(ms2_ms1_rel)
# Add the ms2 -> ms3 "downloads" relationship
ms2_ms3_rel = MalwareSubjectRelationship()
ms2_ms3_rel.type_ = VocabString()
ms2_ms3_rel.type_.value = "downloads"
ms2_ms3_rel.type_.xsi_type = "maecVocabs:MalwareSubjectRelationshipTypeVocab-1.0"
ms2_ms3_rel.malware_subject_reference = [MalwareSubjectReference()]
ms2_ms3_rel.malware_subject_reference[0].malware_subject_idref = ms3.id_
ms2.relationships.append(ms2_ms3_rel)
# Add the ms2 -> ms4 "downloads" relationship
ms2_ms4_rel = MalwareSubjectRelationship()
ms2_ms4_rel.type_ = VocabString()
ms2_ms4_rel.type_.value = "downloads"
ms2_ms4_rel.type_.xsi_type = "maecVocabs:MalwareSubjectRelationshipTypeVocab-1.0"
ms2_ms4_rel.malware_subject_reference = [MalwareSubjectReference()]
ms2_ms4_rel.malware_subject_reference[0].malware_subject_idref = ms4.id_
ms2.relationships.append(ms2_ms4_rel)
# Add the ms3 -> ms2 "downloaded by" relationship
ms3.relationships = MalwareSubjectRelationshipList()
ms3_ms2_rel = MalwareSubjectRelationship()
ms3_ms2_rel.type_ = VocabString()
ms3_ms2_rel.type_.value = "downloaded by"
ms3_ms2_rel.type_.xsi_type = "maecVocabs:MalwareSubjectRelationshipTypeVocab-1.0"
ms3_ms2_rel.malware_subject_reference = [MalwareSubjectReference()]
ms3_ms2_rel.malware_subject_reference[0].malware_subject_idref = ms2.id_
ms3.relationships.append(ms3_ms2_rel)
# Add the ms4 -> ms2 "downloaded by" relationship
ms4.relationships = MalwareSubjectRelationshipList()
ms4_ms2_rel = MalwareSubjectRelationship()
ms4_ms2_rel.type_ = VocabString()
ms4_ms2_rel.type_.value = "downloaded by"
ms4_ms2_rel.type_.xsi_type = "maecVocabs:MalwareSubjectRelationshipTypeVocab-1.0"
ms4_ms2_rel.malware_subject_reference = [MalwareSubjectReference()]
ms4_ms2_rel.malware_subject_reference[0].malware_subject_idref = ms2.id_
ms4.relationships.append(ms4_ms2_rel)

# Build up the full Package/Malware Subject hierarchy
p.add_malware_subject(ms1)
p.add_malware_subject(ms2)
p.add_malware_subject(ms3)
p.add_malware_subject(ms4)

# Output the built up Package to XML
print p.to_xml()

